/* Copyright 2012 Jesper K. Pedersen <blackie@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BACKGROUNDTASKMANAGER_PRIORITYQUEUE_H
#define BACKGROUNDTASKMANAGER_PRIORITYQUEUE_H

#include "Priority.h"

#include <QQueue>
#include <QVector>

namespace BackgroundTaskManager
{

class JobInterface;

class PriorityQueue
{
public:
    PriorityQueue();
    bool isEmpty() const;
    int count() const;
    void enqueue(JobInterface *job, Priority priority);
    JobInterface *dequeue();
    JobInterface *peek(int index) const;
    bool hasForegroundTasks() const;

private:
    typedef QQueue<JobInterface *> QueueType;
    QVector<QueueType> m_jobs;
};

} // namespace BackgroundTaskManager

#endif // BACKGROUNDTASKMANAGER_PRIORITYQUEUE_H
// vi:expandtab:tabstop=4 shiftwidth=4:
